owlrl
=====

.. automodule:: owlrl

   
   
   .. rubric:: Functions

   .. autosummary::
   
      convert_graph
      interpret_owl_imports
      return_closure_class
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      DeductiveClosure
   
   

   
   
   